@@ -3,13 +3,13 @@ from abc import ABC, abstractmethod
 from pandas import DataFrame
 from pydantic.main import BaseModel
 
-from weaverbird.types import DomainRetriever, PipelineExecutor
+from weaverbird.types import DomainRetriever, PipelineExecutor, PopulatedWithFieldnames
 
 
 class BaseStep(BaseModel, ABC):
     name: str
 
-    class Config:
+    class Config(PopulatedWithFieldnames):
         extra = 'forbid'
 
     @abstractmethod
