@@ -1,27 +1,30 @@
-from typing import List, Literal, Tuple
+from typing import List, Literal, Tuple, Union
 
 from pandas import DataFrame, merge
 from pydantic import Field
 
 from weaverbird.steps.base import BaseStep
-from weaverbird.types import ColumnName, PipelineExecutor
+from weaverbird.steps.combination import PipelineOrDomainName, resolve_pipeline_for_combination
+from weaverbird.types import ColumnName, DomainRetriever, PipelineExecutor
 
 JoinColumnsPair = Tuple[ColumnName, ColumnName]
 
 
 class JoinStep(BaseStep):
     name = Field('join', const=True)
-    right_pipeline: List[dict]
+    right_pipeline: Union[PipelineOrDomainName]
     type: Literal['left', 'inner', 'left outer']
     on: List[JoinColumnsPair] = Field(..., min_items=1)
 
     def execute(
         self,
         df: DataFrame,
-        domain_retriever,
+        domain_retriever: DomainRetriever,
         execute_pipeline: PipelineExecutor,
     ) -> DataFrame:
-        right_df = execute_pipeline(self.right_pipeline)
+        right_df = resolve_pipeline_for_combination(
+            self.right_pipeline, domain_retriever, execute_pipeline
+        )
 
         if self.type == 'left outer':
             how = 'outer'
